@@ -64,6 +64,7 @@ gint main (gint argc, gchar *argv[])
   MaximusApp UNUSED_VARIABLE *app;
   GOptionContext  *context;
   GError *error = NULL;
+  GdkDisplay *gdk_display = gdk_display_get_default ();
 
   g_set_application_name ("Maximus");
   
@@ -89,9 +90,9 @@ gint main (gint argc, gchar *argv[])
   g_option_context_parse (context, &argc, &argv, NULL);
   g_option_context_free(context);  
 
-  gdk_error_trap_push ();
+  gdk_x11_display_error_trap_push (gdk_display);
   app = maximus_app_get_default ();
-  gdk_error_trap_pop_ignored ();
+  gdk_x11_display_error_trap_pop_ignored (gdk_display);
 
   gtk_main ();
 
